from pkg_resources import resource_stream

import yaml


def get_data(data_type="suo"):
    stream_args = ["suo", "src/data.yaml"]
    stream = resource_stream(*stream_args)
    data = yaml.load(stream, Loader=yaml.FullLoader)
    stream.close()

    if data_type == "kuo":
        return data
    elif data_type == "suo":
        new_data = {}
        for key, values in data.items():
            for value in values:
                new_data[value] = key
        return new_data
    else:
        raise ValueError(f"type error: {data_type}")


def suo(word):
    data = get_data("suo")
    if word in data.keys():
        return data[word]
    else:
        raise ValueError(f"暂未收录：{word}")


def kuo(word, show_all=False):
    data = get_data("kuo")
    word = word.lower()
    if word in data.keys():
        if show_all:
            return data[word]
        else:
            return data[word][0]
    else:
        raise ValueError(f"暂未收录：{word}")



from setuptools import setup
from setuptools import find_packages

NAME = "suo"
AUTHOR = "Ailln"
EMAIL = "kinggreenhall@gmail.com"
URL = "https://github.com/Ailln/suo"
LICENSE = "MIT License"
DESCRIPTION = "中英文缩写转化"

if __name__ == "__main__":
    setup(
        name=NAME,
        version="0.0.4",
        author=AUTHOR,
        author_email=EMAIL,
        url=URL,
        license=LICENSE,
        description=DESCRIPTION,
        packages=find_packages(),
        include_package_data=True,
        install_requires=open("./requirements.txt", "r").read().splitlines(),
        long_description=open("./README.md", "r").read(),
        long_description_content_type="text/markdown",
        entry_points={
            "console_scripts": [
                "suo=suo.shell:run"
            ]
        },
        package_data={
            "suo": ["src/*.yaml"]
        },
        zip_safe=True,
        classifiers=[
            "Programming Language :: Python :: 3",
            f"License :: OSI Approved :: {LICENSE}",
            "Operating System :: OS Independent"
        ],
        python_requires=">=3.6"
    )
